AbstractFunction class abstract

Abstract implementation of a direct function.

This abstract implementation does implement lazyEval so that it returns the result of eval.

Inheritance
Implemented types
Implementers

Constructors

AbstractFunction(String name, int numParams, {bool booleanFunction = false})
Creates a new function with given name and parameter count.

Properties

booleanFunction ↔ bool
Whether this function is a boolean function.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
Name of this function.
getter/setter pairinherited
numParams ↔ int
Number of parameters expected for this function. -1 denotes a variable number of parameters.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(List<Decimal?> parameters) → Decimal
Implementation for this function.
inherited
getName() → String
Gets the name of this function.

The name is use to invoke this function in the expression.
inherited
getNumParams() → int
Gets the number of parameters this function accepts.
inherited
isBooleanFunction() → bool
Gets whether this function evaluates to a boolean expression.
inherited
lazyEval(List<LazyNumber> lazyParams) → LazyNumber
Lazily evaluate this function.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
numParamsVaries() → bool
Gets whether the number of accepted parameters varies.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited