AbstractLazyFunction class abstract

Abstract implementation of a lazy function which implements all necessary methods with the exception of the main logic.

Implemented types
Implementers

Constructors

AbstractLazyFunction(String name, int numParams, {bool booleanFunction = false})
Creates a new function with given name and parameter count.

Properties

booleanFunction ↔ bool
Whether this function is a boolean function.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
Name of this function.
getter/setter pair
numParams ↔ int
Number of parameters expected for this function. -1 denotes a variable number of parameters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getName() → String
Gets the name of this function.

The name is use to invoke this function in the expression.
override
getNumParams() → int
Gets the number of parameters this function accepts.
override
isBooleanFunction() → bool
Gets whether this function evaluates to a boolean expression.
override
lazyEval(List<LazyNumber> lazyParams) → LazyNumber
Lazily evaluate this function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
numParamsVaries() → bool
Gets whether the number of accepted parameters varies.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited