AbstractLazyOperator class abstract

Abstract implementation of an operator.

Implemented types
Implementers

Constructors

AbstractLazyOperator(String oper, int precedence, bool leftAssoc, {bool booleanOperator = false, bool unaryOperator = false})
Creates a new operator.

Properties

booleanOperator ↔ bool
Whether this operator is boolean or not.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
leftAssoc ↔ bool
Operator is left associative.
getter/setter pair
oper ↔ String
This operators name (pattern).
getter/setter pair
precedence ↔ int
Operators precedence.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unaryOperator ↔ bool
getter/setter pair

Methods

evalLazy(LazyNumber v1, LazyNumber? v2) → LazyNumber
Implementation for this operator.
inherited
getOper() → String
Gets the String that is used to denote the operator in the expression.
override
getPrecedence() → int
Gets the precedence value of this operator.
override
isBooleanOperator() → bool
Gets whether this operator evaluates to a boolean expression. Returns true if this operator evaluates to a boolean expression.
override
isLeftAssoc() → bool
Gets whether this operator is left associative (true) or if this operator is right associative (false).
override
isUnaryOperator() → bool
True if the number of operands for this operator is 1, false if it is 2.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited