UnaryOperatorImpl class

Inheritance

Constructors

UnaryOperatorImpl(String oper, int precedence, bool leftAssoc, {required dynamic fEval(Decimal v1)})

Properties

booleanOperator ↔ bool
Whether this operator is boolean or not.
getter/setter pairinherited
fEval ↔ dynamic Function(Decimal v1)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
leftAssoc ↔ bool
Operator is left associative.
getter/setter pairinherited
oper ↔ String
This operators name (pattern).
getter/setter pairinherited
precedence ↔ int
Operators precedence.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unaryOperator ↔ bool
getter/setter pairinherited

Methods

eval(Decimal? v1, Decimal? v2) → Decimal
Implementation for this operator.
inherited
evalLazy(LazyNumber v1, LazyNumber? v2) → LazyNumber
Implementation for this operator.
inherited
evalUnary(Decimal? v1) → Decimal
override
getOper() → String
Gets the String that is used to denote the operator in the expression.
inherited
getPrecedence() → int
Gets the precedence value of this operator.
inherited
isBooleanOperator() → bool
Gets whether this operator evaluates to a boolean expression. Returns true if this operator evaluates to a boolean expression.
inherited
isLeftAssoc() → bool
Gets whether this operator is left associative (true) or if this operator is right associative (false).
inherited
isUnaryOperator() → bool
True if the number of operands for this operator is 1, false if it is 2.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited