IFunc class abstract

Base interface which is required for all directly evaluated functions.

Inheritance
Implementers

Constructors

IFunc()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(List<Decimal?> parameters) → Decimal
Implementation for this function.
getName() → String
Gets the name of this function.

The name is use to invoke this function in the expression.
inherited
getNumParams() → int
Gets the number of parameters this function accepts.
inherited
isBooleanFunction() → bool
Gets whether this function evaluates to a boolean expression.
inherited
lazyEval(List<LazyNumber> lazyParams) → LazyNumber
Lazily evaluate this function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
numParamsVaries() → bool
Gets whether the number of accepted parameters varies.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited