ILazyFunction class abstract

Base interface which is required for lazily evaluated functions. A function is defined by a name, a number of parameters it accepts and of course the logic for evaluating the result.

Implementers

Constructors

ILazyFunction()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getName() → String
Gets the name of this function.

The name is use to invoke this function in the expression.
getNumParams() → int
Gets the number of parameters this function accepts.
isBooleanFunction() → bool
Gets whether this function evaluates to a boolean expression.
lazyEval(List<LazyNumber> lazyParams) → LazyNumber
Lazily evaluate this function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
numParamsVaries() → bool
Gets whether the number of accepted parameters varies.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited