IOperator class abstract

Abstract class AbstractOperator accepts postfix unary operators with the second operand v2=null.

Inheritance
Implementers

Constructors

IOperator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(Decimal? v1, Decimal? v2) → Decimal
Implementation for this operator.
evalLazy(LazyNumber v1, LazyNumber? v2) → LazyNumber
Implementation for this operator.
inherited
getOper() → String
Gets the String that is used to denote the operator in the expression.
inherited
getPrecedence() → int
Gets the precedence value of this operator.
inherited
isBooleanOperator() → bool
Gets whether this operator evaluates to a boolean expression. Returns true if this operator evaluates to a boolean expression.
inherited
isLeftAssoc() → bool
Gets whether this operator is left associative (true) or if this operator is right associative (false).
inherited
isUnaryOperator() → bool
True if the number of operands for this operator is 1, false if it is 2.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited